import webbrowser

class RepoVisibility(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class RepoSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class RepoType(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class RepoAffiliation(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class RepoDirection(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class ReposMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
