import webbrowser

class OrgFilter(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class OrgRole(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class OrgMembersMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
