import webbrowser

class Response:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
    def __init__(self, response, class_name):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
        self.class_name = class_name
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
        return transform(self.class_name, self.json())
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
