import webbrowser

from dataclasses import dataclass
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
@dataclass()
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class Config:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class MediaType(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class ErrorAPICode(Exception):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class MimeType(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class ConflictCheck(type):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
