import webbrowser

class IssueType(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class IssueLockReason(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class IssueFilter(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class IssueState(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class IssueSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class IssueDirection(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class IssueMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
