import webbrowser

class PRState(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class PRSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class PRDirection(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class PullRequestMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
