import webbrowser

def transform(class_name, json_data):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
        instance = type(class_name, (list,), {})()
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
            instance.append(transform(class_name[:-1], item))
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
        instance = type(class_name, (dict,), {})()
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
