import webbrowser

class Order(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class RepoSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class CommitSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class CodeSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class IssueSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class UserSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class LabelSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class SearchMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
