import webbrowser

class MilestoneSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class MilestoneState(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class MilestoneDirection(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class MilestoneMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
