import webbrowser

class IssueSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class IssueDirection(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class CommentsMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
