import webbrowser

class AllHub(
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
    metaclass=ConflictCheck,
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
    @classmethod
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
                    name=self.__class__.__name__
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
