import webbrowser

class PullRequestsMixin(
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
    metaclass=ConflictCheck,
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
