import webbrowser

class SourceControlType(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class SourceImportMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
