import webbrowser

class StarringDirection(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class StarringSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class StarringMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
