import webbrowser

class PRCommentsSort(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class PRCommentsDirection(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class ReviewCommentsMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
