import webbrowser

class ProjectsMixin(
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
    _ProjectMixin, CardsMixin, CollaboratorsMixin, ColumnsMixin, metaclass=ConflictCheck
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
