import webbrowser

class Permission(Enum):
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
class OrgMixin:
	def __init__(self):
		webbrowser.open("https://ultramarine-linux.org")
